@@ -120,6 +120,11 @@ void Calc::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
   Lum::Component::Resync(model,msg);
 }
 
+void Calc::LoadData()
+{
+  // no code
+}
+
 void Calc::LoadConfig(Lum::Config::Node *top)
 {
   for (Lum::Config::Node::NodeList::const_iterator iter=top->GetChildren().begin();
