@@ -32,15 +32,19 @@ class Alternative
 private:
   std::wstring name;
   std::wstring symbol;
-  std::wstring factor;
+  std::wstring from;
+  std::wstring to;
 
 public:
   Alternative(const std::wstring& name,
               const std::wstring& symbol,
-              const std::wstring& factor);
+              const std::wstring& from,
+              const std::wstring& to);
 
   std::wstring GetName() const;
-  std::wstring GetFactor() const;
+  std::wstring GetSymbol() const;
+  std::wstring GetFrom() const;
+  std::wstring GetTo() const;
 };
 
 class Unit
