@@ -35,7 +35,7 @@
 
 #define LEADING_PAGES 1
 #define TRAILING_PAGES 1
-#include <iostream>
+
 void ListCategories(const std::wstring& category, std::vector<std::wstring>& subs)
 {
   size_t start,pos;
@@ -212,14 +212,23 @@ public:
     label->AddLabel(L"Formula:",formula->GetFormula());
     label->AddLabel(L"Description:",formula->GetDescription());
 
-    resUnit=new Lum::Model::SizeT(1);
+    resUnit=new Lum::Model::SizeT();
     resUnitList=new Lum::Model::StringTable();
     unit=unitMap[formula->GetUnit()];
 
     for (size_t j=0; j<unit->GetAlternativeCount(); j++) {
+      if (resUnit->IsNull() &&
+          unit->GetAlternative(j)->GetFrom()==L"x" &&
+          unit->GetAlternative(j)->GetTo()==L"x") {
+        resUnit->Set(j+1);
+      }
       resUnitList->Append(unit->GetAlternative(j)->GetName());
     }
 
+    if (resUnit->IsNull()) {
+      resUnit->Set(1);
+    }
+
     Lum::Def::OneOfMany resUnitDef(Lum::Def::Desc(L"Unit"),
                                 resUnit,resUnitList);
 
@@ -236,7 +245,7 @@ public:
     wizard->AddPage(L"Unit of Result",panel,stepAction);
 
     for (size_t i=0; i<formula->GetVariables().size(); i++) {
-      Lum::Model::SizeTRef       srcUnit=new Lum::Model::SizeT(1);
+      Lum::Model::SizeTRef       srcUnit=new Lum::Model::SizeT();
       Lum::Model::StringTableRef srcUnitList=new Lum::Model::StringTable();
 
       Lum::Model::StringRef value=new Lum::Model::String(L"");
@@ -246,9 +255,19 @@ public:
       unit=unitMap[formula->GetVariables()[i]->GetUnit()];
 
       for (size_t j=0; j<unit->GetAlternativeCount(); j++) {
+        if (srcUnit->IsNull() &&
+            unit->GetAlternative(j)->GetFrom()==L"x" &&
+            unit->GetAlternative(j)->GetTo()==L"x") {
+          srcUnit->Set(j+1);
+        }
+
         srcUnitList->Append(unit->GetAlternative(j)->GetName());
       }
 
+      if (resUnit->IsNull()) {
+        resUnit->Set(1);
+      }
+
       panel=Lum::VPanel::Create(true,true);
 
       label=Lum::Label::Create(true,false);
@@ -266,7 +285,7 @@ public:
       Lum::Def::OneOfMany srcUnitDef(Lum::Def::Desc(L"Unit"),
                                      srcUnit,srcUnitList);
 
-      oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(resUnitDef);
+      oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(srcUnitDef);
       oneOfMany->SetFlex(true,false);
       label->AddLabel(L"Unit:",oneOfMany);
 
@@ -316,7 +335,8 @@ public:
           size_t             pos;
 
           if (!srcValues[i]->Get().empty()) {
-            expression=parser.Parse(Lum::Base::WStringToString(srcValues[i]->Get()),returnCode,pos,false);
+            expression=parser.Parse(Lum::Base::WStringToString(srcValues[i]->Get()),
+                                    returnCode,pos,false);
           }
 
           if (expression==NULL) {
@@ -334,6 +354,8 @@ public:
 
       for (size_t i=LEADING_PAGES; i<stepActions.size(); i++) {
         if (model==stepActions[i] && stepActions[i]->IsFinished()) {
+          Parser unitParser;
+          Parser::Variable* variable=unitParser.AddVariable("x",0.0);
 
           for (size_t j=0; j<i; j++) {
             Unit               *unit;
@@ -341,24 +363,28 @@ public:
             Parser::ReturnCode returnCode;
             size_t             pos;
             bool               success;
-            double             factor;
             double             value;
 
-            // Factor
-            unit=unitMap[formula->GetVariables()[j]->GetUnit()];
-            expression=parser.Parse(Lum::Base::WStringToString(unit->GetAlternative(srcUnits[j]->Get()-1)->GetFactor()),returnCode,pos,false);
-            assert(expression!=NULL);
-            success=expression->Calculate(factor,returnCode);
-            assert(success);
-            delete expression;
-
             // Value
-            expression=parser.Parse(Lum::Base::WStringToString(srcValues[j]->Get()),returnCode,pos,false);
+            expression=parser.Parse(Lum::Base::WStringToString(srcValues[j]->Get()),
+                                    returnCode,pos,false);
             assert(expression!=NULL);
             success=expression->Calculate(value,returnCode);
             assert(success);
-            parser.AddConstant(Lum::Base::WStringToString(formula->GetVariables()[j]->GetName()),value/factor);
             delete expression;
+
+            // Factor
+            unit=unitMap[formula->GetVariables()[j]->GetUnit()];
+            variable->value=value;
+            expression=unitParser.Parse(Lum::Base::WStringToString(unit->GetAlternative(srcUnits[j]->Get()-1)->GetFrom()),
+                                        returnCode,pos,false);
+            assert(expression!=NULL);
+            success=expression->Calculate(value,returnCode);
+            assert(success);
+            delete expression;
+
+            parser.AddConstant(Lum::Base::WStringToString(formula->GetVariables()[j]->GetName()),
+                               value);
           }
 
           if (i==stepActions.size()-1) {
@@ -367,24 +393,27 @@ public:
             Parser::ReturnCode returnCode;
             size_t             pos;
             bool               success;
-            double             factor;
             double             value;
 
-            //Factor
-            unit=unitMap[formula->GetUnit()];
-            expression=parser.Parse(Lum::Base::WStringToString(unit->GetAlternative(resUnit->Get()-1)->GetFactor()),returnCode,pos,false);
-            assert(expression!=NULL);
-            success=expression->Calculate(factor,returnCode);
-            assert(success);
-            delete expression;
-
             // Value
-            expression=parser.Parse(Lum::Base::WStringToString(formula->GetFormula()),returnCode,pos,false);
+            expression=parser.Parse(Lum::Base::WStringToString(formula->GetFormula()),
+                                    returnCode,pos,false);
             assert(expression!=NULL);
             success=expression->Calculate(value,returnCode);
             assert(success);
-            result->Set(DoubleToWStringFloat(factor*value)+L" "+unit->GetAlternative(resUnit->Get()-1)->GetName());
             delete expression;
+
+            //Factor
+            unit=unitMap[formula->GetUnit()];
+            variable->value=value;
+            expression=unitParser.Parse(Lum::Base::WStringToString(unit->GetAlternative(resUnit->Get()-1)->GetTo()),
+                                        returnCode,pos,false);
+            assert(expression!=NULL);
+            success=expression->Calculate(value,returnCode);
+            assert(success);
+            delete expression;
+
+            result->Set(DoubleToWStringFloat(value)+L" "+unit->GetAlternative(resUnit->Get()-1)->GetName());
           }
 
           break;
@@ -524,7 +553,6 @@ void FormulaCalc::LoadData()
   std::set<std::wstring> categories;
 
   for (size_t i=0; i<formulas.size(); i++) {
-    std::cout << "Formula " << i << std::endl;
     std::vector<std::wstring> subs;
 
     ListCategories(formulas[i]->GetCategory(),subs);
