@@ -139,14 +139,17 @@ public:
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
   {
-    if (model==GetOpenedAction() && GetOpenedAction()->IsFinished()) {
-      LoadData();
+    if (model==GetOpenedAction() &&
+        GetOpenedAction()->IsFinished()) {
+      LoadData(plugins);
       LoadConfig(plugins);
     }
-    else if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
+    else if (model==GetClosedAction() &&
+             GetClosedAction()->IsFinished()) {
       SaveConfig(plugins);
     }
-    else if (model==settingsAction && settingsAction->IsFinished()) {
+    else if (model==settingsAction &&
+             settingsAction->IsFinished()) {
       ConfigDialog *dialog;
 
       dialog=new ConfigDialog();
@@ -158,7 +161,8 @@ public:
 
       delete dialog;
     }
-    else if (model==aboutAction && aboutAction->IsFinished()) {
+    else if (model==aboutAction &&
+             aboutAction->IsFinished()) {
       Lum::Dlg::About::Show(this,info);
     }
 
