@@ -24,6 +24,8 @@
 
 #include <Lum/Model/Table.h>
 
+#include <Lum/OS/Color.h>
+
 #include <Lum/Object.h>
 
 #include "Parser.h"
@@ -86,6 +88,11 @@ private:
   double              right;
   bool                areaSelection;
   size_t              assx,assy,asex,asey;
+  Lum::OS::ColorRef   backgroundColor;
+  Lum::OS::ColorRef   gridAColor;
+  Lum::OS::ColorRef   gridBColor;
+  Lum::OS::ColorRef   axisColor;
+  Lum::OS::ColorRef   lineColor;
 
 private:
   int TransformX(double x);
